Table Processors
=================

.. contents::
    :depth: 2
    :local:
    :backlinks: top

.. automodule:: burdoc.processors.table_processors
   :members:

Rules-based Processors
-----------------------
.. autoclass:: burdoc.processors.table_processors.rules_table_processor.RulesTableProcessor
    :members:


ML-based Processors
-------------------
.. autoclass:: burdoc.processors.table_processors.ml_table_processor.MLTableProcessor
    :members:


.. autoclass:: burdoc.processors.table_processors.detr_table_strategy.DetrTableStrategy
    :members:


Strategy Interface Class
------------------------
.. autoclass:: burdoc.processors.table_processors.table_extractor_strategy.TableExtractorStrategy
    :members:




